@@ -14,6 +14,7 @@
  */
 package org.apache.geode.modules.session.catalina;
 
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
 
 import java.io.DataInput;
 import java.io.DataOutput;
@@ -57,7 +58,7 @@ import org.apache.geode.modules.session.catalina.internal.DeltaSessionUpdateAttr
 public class DeltaSession extends StandardSession
     implements DataSerializable, Delta, GatewayDelta, Sizeable, DeltaSessionInterface {
 
-  private transient Region<String, HttpSession> operatingRegion;
+  private transient Region<String, DeltaSessionInterface> operatingRegion;
 
   private String sessionRegionName;
 
@@ -189,7 +190,7 @@ public class DeltaSession extends StandardSession
     return serializedPrincipal;
   }
 
-  private Region<String, HttpSession> getOperatingRegion() {
+  private Region<String, DeltaSessionInterface> getOperatingRegion() {
     // This region shouldn't be null when it is needed.
     // It should have been set by the setOwner method.
     return operatingRegion;
@@ -253,7 +254,7 @@ public class DeltaSession extends StandardSession
 
     synchronized (changeLock) {
       // Serialize the value
-      final byte[] serializedValue = value == null ? null : serialize(value);
+      byte[] serializedValue = serialize(value);
 
       // Store the attribute locally
       if (preferDeserializedForm) {
@@ -265,9 +266,7 @@ public class DeltaSession extends StandardSession
         super.setAttribute(name, serializedValue, true);
       }
 
-      // super.setAttribute above performed a removeAttribute for a value which was null once
-      // deserialized.
-      if (value == null) {
+      if (serializedValue == null) {
         return;
       }
 
@@ -333,9 +332,6 @@ public class DeltaSession extends StandardSession
 
   @Override
   public Object getAttribute(String name) {
-    if (name == null) {
-      return null;
-    }
     checkBackingCacheAvailable();
     Object value = deserializeAttribute(name, super.getAttribute(name), preferDeserializedForm);
 
@@ -357,10 +353,6 @@ public class DeltaSession extends StandardSession
     if (value instanceof byte[]) {
       try {
         final Object deserialized = BlobHelper.deserializeBlob((byte[]) value);
-        if (deserialized == null) {
-          removeAttributeInternal(name, false);
-          return null;
-        }
         if (store) {
           setAttributeInternal(name, deserialized);
         }
@@ -480,13 +472,13 @@ public class DeltaSession extends StandardSession
     // session region if local cache is enabled; otherwise, it will be the
     // session region itself.
     // If a CS manager is used, it will be the session proxy region.
-    operatingRegion = sessionManager.getSessionCache().getOperatingRegion();
+    operatingRegion = uncheckedCast(sessionManager.getSessionCache().getOperatingRegion());
     if (sessionManager.getLogger().isDebugEnabled()) {
       sessionManager.getLogger().debug(this + ": Set operating region: " + operatingRegion);
     }
   }
 
-  void queueAttributeEvent(DeltaSessionAttributeEvent event,
+  private void queueAttributeEvent(DeltaSessionAttributeEvent event,
       boolean checkAddToCurrentGatewayDelta) {
     // Add to current gateway delta if necessary
     if (checkAddToCurrentGatewayDelta) {
@@ -508,7 +500,7 @@ public class DeltaSession extends StandardSession
     addEventToEventQueue(event);
   }
 
-  private void putInRegion(Region region, boolean applyRemotely,
+  private void putInRegion(Region<String, DeltaSessionInterface> region, boolean applyRemotely,
       Object callbackArgument) {
     hasDelta = true;
     this.applyRemotely = applyRemotely;
@@ -688,8 +680,7 @@ public class DeltaSession extends StandardSession
   @Override
   public int getSizeInBytes() {
     int size = 0;
-    @SuppressWarnings("unchecked")
-    Enumeration<String> attributeNames = getAttributeNames();
+    Enumeration<String> attributeNames = uncheckedCast(getAttributeNames());
     while (attributeNames.hasMoreElements()) {
       // Don't use getAttribute() because we don't want to deserialize the value.
       Object value = getAttributeWithoutDeserialize(attributeNames.nextElement());
@@ -701,13 +692,11 @@ public class DeltaSession extends StandardSession
     return size;
   }
 
-  @SuppressWarnings({"unchecked", "rawtypes"})
   private Map<String, byte[]> getSerializedAttributes() {
     // Iterate the values and serialize them if necessary before sending them to the server. This
     // makes the application classes unnecessary on the server.
     Map<String, byte[]> serializedAttributes = new ConcurrentHashMap<>();
-    for (Object o : getAttributes().entrySet()) {
-      Map.Entry<String, Object> entry = (Map.Entry<String, Object>) o;
+    for (Map.Entry<String, Object> entry : getAttributes().entrySet()) {
       Object value = entry.getValue();
       byte[] serializedValue = value instanceof byte[] ? (byte[]) value : serialize(value);
       serializedAttributes.put(entry.getKey(), serializedValue);
@@ -715,10 +704,10 @@ public class DeltaSession extends StandardSession
     return serializedAttributes;
   }
 
-  protected Map getAttributes() {
+  protected Map<String, Object> getAttributes() {
     try {
       Field field = getAttributesFieldObject();
-      return (Map) field.get(this);
+      return uncheckedCast(field.get(this));
     } catch (IllegalAccessException e) {
       logError(e);
     }
