@@ -124,33 +124,9 @@ public class CacheClientNotifier {
   @MakeNotStatic
   private static volatile CacheClientNotifier ccnSingleton;
 
-  private final SocketMessageWriter socketMessageWriter;
+  private final SocketMessageWriter socketMessageWriter = new SocketMessageWriter();
   private final ClientRegistrationEventQueueManager clientRegistrationEventQueueManager;
-
-  @VisibleForTesting
-  static CacheClientNotifier getInstance(InternalCache cache,
-      ClientRegistrationEventQueueManager clientRegistrationEventQueueManager,
-      StatisticsClock statisticsClock,
-      CacheServerStats acceptorStats,
-      int maximumMessageCount,
-      int messageTimeToLive,
-      ConnectionListener listener,
-      OverflowAttributes overflowAttributes,
-      boolean isGatewayReceiver,
-      SocketMessageWriter socketMessageWriter) {
-    if (ccnSingleton == null) {
-      ccnSingleton = new CacheClientNotifier(cache, clientRegistrationEventQueueManager,
-          statisticsClock, acceptorStats, maximumMessageCount, messageTimeToLive, listener,
-          isGatewayReceiver, socketMessageWriter);
-    }
-
-    if (!isGatewayReceiver && ccnSingleton.getHaContainer() == null) {
-      // Gateway receiver might have create CCN instance without HaContainer
-      // In this case, the HaContainer should be lazily created here
-      ccnSingleton.initHaContainer(overflowAttributes);
-    }
-    return ccnSingleton;
-  }
+  private final CacheClientProxyFactory cacheClientProxyFactory;
 
   /**
    * Factory method to construct a CacheClientNotifier {@code CacheClientNotifier} instance.
@@ -168,9 +144,18 @@ public class CacheClientNotifier {
       ConnectionListener listener,
       OverflowAttributes overflowAttributes,
       boolean isGatewayReceiver) {
-    return getInstance(cache, clientRegistrationEventQueueManager, statisticsClock,
-        acceptorStats, maximumMessageCount, messageTimeToLive, listener, overflowAttributes,
-        isGatewayReceiver, new SocketMessageWriter());
+    if (ccnSingleton == null) {
+      ccnSingleton = new CacheClientNotifier(cache, clientRegistrationEventQueueManager,
+          statisticsClock, acceptorStats, maximumMessageCount, messageTimeToLive, listener,
+          isGatewayReceiver, new CacheClientProxyFactory());
+    }
+
+    if (!isGatewayReceiver && ccnSingleton.getHaContainer() == null) {
+      // Gateway receiver might have create CCN instance without HaContainer
+      // In this case, the HaContainer should be lazily created here
+      ccnSingleton.initHaContainer(overflowAttributes);
+    }
+    return ccnSingleton;
   }
 
   public static CacheClientNotifier getInstance() {
@@ -313,9 +298,9 @@ public class CacheClientNotifier {
               clientProxyMembershipID.getDurableId());
         }
         cacheClientProxy =
-            new CacheClientProxy(this, socket, clientProxyMembershipID, isPrimary, clientConflation,
-                clientVersion, acceptorId, notifyBySubscription, cache.getSecurityService(),
-                subject, statisticsClock);
+            cacheClientProxyFactory.create(this, socket, clientProxyMembershipID, isPrimary,
+                clientConflation, clientVersion, acceptorId, notifyBySubscription,
+                cache.getSecurityService(), subject, statisticsClock);
         successful = initializeProxy(cacheClientProxy);
       } else {
         cacheClientProxy.setSubject(subject);
@@ -449,19 +434,15 @@ public class CacheClientNotifier {
       if (logger.isDebugEnabled()) {
         logger.debug("CacheClientNotifier: Successfully registered {}", cacheClientProxy);
       }
-      performPostAuthorization(cacheClientProxy, clientProxyMembershipID, member,
-          sysProps,
-          subjectOrPrincipal);
     } else {
-      try {
-        // prevent leak by closing socket
-        socket.close();
-      } catch (IOException ignore) {
-      }
       logger.warn(
           "CacheClientNotifier: Unsuccessfully registered client with identifier {} and response code {}",
           new Object[] {clientProxyMembershipID, responseByte});
     }
+
+    performPostAuthorization(cacheClientProxy, clientProxyMembershipID, member,
+        sysProps,
+        subjectOrPrincipal);
   }
 
   private void handleAuthenticationException(final ClientProxyMembershipID clientProxyMembershipID,
@@ -1680,7 +1661,7 @@ public class CacheClientNotifier {
   /**
    * Returns this {@code CacheClientNotifier}'s {@code InternalCache}.
    */
-  protected InternalCache getCache() {
+  public InternalCache getCache() {
     if (cache != null && cache.isClosed()) {
       InternalCache cache = GemFireCacheImpl.getInstance();
       if (cache != null) {
@@ -1722,12 +1703,13 @@ public class CacheClientNotifier {
   private CacheClientNotifier(InternalCache cache,
       ClientRegistrationEventQueueManager clientRegistrationEventQueueManager,
       StatisticsClock statisticsClock,
-      CacheServerStats acceptorStats, int maximumMessageCount,
+      CacheServerStats acceptorStats,
+      int maximumMessageCount,
       int messageTimeToLive,
       ConnectionListener listener,
       boolean isGatewayReceiver,
-      SocketMessageWriter socketMessageWriter) {
-    this.socketMessageWriter = socketMessageWriter;
+      CacheClientProxyFactory cacheClientProxyFactory) {
+    this.cacheClientProxyFactory = cacheClientProxyFactory;
     // Set the Cache
     setCache(cache);
     this.clientRegistrationEventQueueManager = clientRegistrationEventQueueManager;
